@@ -1151,7 +1151,7 @@ dynamicforms = {
         if (data.length > 0) {
           table.append(data);
           tbl_pagination.trigger_element = data[0];
-          if (table.find("tr[data-title=NoData]").length > 0) {
+          if (table.find("tr").length > 1 && table.find("tr[data-title=NoData]").length > 0) {
             table.find("tr[data-title=NoData]").remove()
           }
         }
@@ -1242,16 +1242,31 @@ dynamicforms = {
     return link_next != null && link_next != undefined && link_next != '' && link_next != "None";
   },
 
-  select2Opening: function select2Opening(evt, $select2, fnc) {
+  select2Opening: function select2Opening(evt, $select2, fnc, params) {
     if ($select2.data('unselecting')) {
       $select2.removeData('unselecting');
       evt.preventDefault();
-    } else if (fnc != null)
-      fnc(evt, $select2);
+    } else if (fnc != null){
+      if(params != undefined)
+        fnc(evt, $select2, params);
+      else
+        fnc(evt, $select2);
+    }
+
+
   },
 
   select2Unselecting: function select2Unselecting($select2) {
     $select2.data('unselecting', true);
+  },
+
+  select2UpdateConfiguration: function select2UpdateConfiguration($select2, conf) {
+    var sel2Conf = $select2.data('sel2Conf');
+    Object.keys(conf).forEach(function(key) {
+      sel2Conf[key] = conf[key];
+    });
+    $select2.select2("destroy").select2(sel2Conf);
+    $select2.data('sel2Conf', sel2Conf);
   }
 
 };
